
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkatepartinterfaces.so )
( cd usr/lib ; ln -sf libkatepartinterfaces.so.4 libkatepartinterfaces.so )
( cd usr/lib ; rm -rf libkateinterfaces.so )
( cd usr/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
( cd usr/lib ; rm -rf libkateinterfaces.so.4 )
( cd usr/lib ; ln -sf libkateinterfaces.so.4.10.5 libkateinterfaces.so.4 )
( cd usr/lib ; rm -rf libkatepartinterfaces.so.4 )
( cd usr/lib ; ln -sf libkatepartinterfaces.so.4.10.5 libkatepartinterfaces.so.4 )
( cd usr/doc/HTML/en/kate ; rm -rf common )
( cd usr/doc/HTML/en/kate ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kwrite ; rm -rf common )
( cd usr/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
